@@ -9,7 +9,7 @@ class Pref_Filters extends Handler_Protected {
 	}
 
 	function filtersortreset() {
-		db_query($this->link, "UPDATE ttrss_filters2
+		$this->dbh->query("UPDATE ttrss_filters2
 				SET order_id = 0 WHERE owner_uid = " . $_SESSION["uid"]);
 		return;
 	}
@@ -31,7 +31,7 @@ class Pref_Filters extends Handler_Protected {
 
 				if ($filter_id > 0) {
 
-					db_query($this->link, "UPDATE ttrss_filters2 SET
+					$this->dbh->query("UPDATE ttrss_filters2 SET
 						order_id = $index WHERE id = '$filter_id' AND
 						owner_uid = " .$_SESSION["uid"]);
 
@@ -49,16 +49,16 @@ class Pref_Filters extends Handler_Protected {
 
 		$filter["enabled"] = true;
 		$filter["match_any_rule"] = sql_bool_to_bool(
-			checkbox_to_sql_bool(db_escape_string($this->link, $_REQUEST["match_any_rule"])));
+			checkbox_to_sql_bool($this->dbh->escape_string($_REQUEST["match_any_rule"])));
 		$filter["inverse"] = sql_bool_to_bool(
-			checkbox_to_sql_bool(db_escape_string($this->link, $_REQUEST["inverse"])));
+			checkbox_to_sql_bool($this->dbh->escape_string($_REQUEST["inverse"])));
 
 		$filter["rules"] = array();
 
-		$result = db_query($this->link, "SELECT id,name FROM ttrss_filter_types");
+		$result = $this->dbh->query("SELECT id,name FROM ttrss_filter_types");
 
 		$filter_types = array();
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
 			$filter_types[$line["id"]] = $line["name"];
 		}
 
@@ -83,9 +83,7 @@ class Pref_Filters extends Handler_Protected {
 			}
 		}
 
-		$feed_title = getFeedTitle($this->link, $feed);
-
-		$qfh_ret = queryFeedHeadlines($this->link, -4, 30, "", false, false, false,
+		$qfh_ret = queryFeedHeadlines(-4, 30, "", false, false, false,
 			"date_entered DESC", 0, $_SESSION["uid"], $filter);
 
 		$result = $qfh_ret[0];
@@ -98,13 +96,17 @@ class Pref_Filters extends Handler_Protected {
 		print "<div class=\"filterTestHolder\">";
 		print "<table width=\"100%\" cellspacing=\"0\" id=\"prefErrorFeedList\">";
 
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
+			$line["content_preview"] = truncate_string(strip_tags($line["content_preview"]), 100, '...');
+
+			foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_QUERY_HEADLINES) as $p) {
+					$line = $p->hook_query_headlines($line, 100);
+				}
 
 			$entry_timestamp = strtotime($line["updated"]);
-			$entry_tags = get_article_tags($this->link, $line["id"], $_SESSION["uid"]);
+			$entry_tags = get_article_tags($line["id"], $_SESSION["uid"]);
 
-			$content_preview = truncate_string(
-				strip_tags($line["content_preview"]), 100, '...');
+			$content_preview = $line["content_preview"];
 
 			if ($line["feed_title"])
 				$feed_title = $line["feed_title"];
@@ -158,7 +160,7 @@ class Pref_Filters extends Handler_Protected {
 
 		$filter_search = $_SESSION["prefs_filter_search"];
 
-		$result = db_query($this->link, "SELECT *,
+		$result = $this->dbh->query("SELECT *,
 			(SELECT action_param FROM ttrss_filters2_actions
 				WHERE filter_id = ttrss_filters2.id ORDER BY id LIMIT 1) AS action_param,
 			(SELECT action_id FROM ttrss_filters2_actions
@@ -176,7 +178,7 @@ class Pref_Filters extends Handler_Protected {
 		$folder = array();
 		$folder['items'] = array();
 
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
 
 			/* if ($action_id != $line["action_id"]) {
 				if (count($folder['items']) > 0) {
@@ -194,10 +196,10 @@ class Pref_Filters extends Handler_Protected {
 
 			$match_ok = false;
 			if ($filter_search) {
-				$rules_result = db_query($this->link,
+				$rules_result = $this->dbh->query(
 					"SELECT reg_exp FROM ttrss_filters2_rules WHERE filter_id = ".$line["id"]);
 
-				while ($rule_line = db_fetch_assoc($rules_result)) {
+				while ($rule_line = $this->dbh->fetch_assoc($rules_result)) {
 					if (mb_strpos($rule_line['reg_exp'], $filter_search) !== false) {
 						$match_ok = true;
 						break;
@@ -206,13 +208,13 @@ class Pref_Filters extends Handler_Protected {
 			}
 
 			if ($line['action_id'] == 7) {
-				$label_result = db_query($this->link, "SELECT fg_color, bg_color
-					FROM ttrss_labels2 WHERE caption = '".db_escape_string($this->link, $line['action_param'])."' AND
+				$label_result = $this->dbh->query("SELECT fg_color, bg_color
+					FROM ttrss_labels2 WHERE caption = '".$this->dbh->escape_string($line['action_param'])."' AND
 						owner_uid = " . $_SESSION["uid"]);
 
-				if (db_num_rows($label_result) > 0) {
-					$fg_color = db_fetch_result($label_result, 0, "fg_color");
-					$bg_color = db_fetch_result($label_result, 0, "bg_color");
+				if ($this->dbh->num_rows($label_result) > 0) {
+					$fg_color = $this->dbh->fetch_result($label_result, 0, "fg_color");
+					$bg_color = $this->dbh->fetch_result($label_result, 0, "bg_color");
 
 					$name[1] = "<span class=\"labelColorIndicator\" id=\"label-editor-indicator\" style='color : $fg_color; background-color : $bg_color; margin-right : 4px'>&alpha;</span>" . $name[1];
 				}
@@ -248,15 +250,15 @@ class Pref_Filters extends Handler_Protected {
 
 	function edit() {
 
-		$filter_id = db_escape_string($this->link, $_REQUEST["id"]);
+		$filter_id = $this->dbh->escape_string($_REQUEST["id"]);
 
-		$result = db_query($this->link,
+		$result = $this->dbh->query(
 			"SELECT * FROM ttrss_filters2 WHERE id = '$filter_id' AND owner_uid = " . $_SESSION["uid"]);
 
-		$enabled = sql_bool_to_bool(db_fetch_result($result, 0, "enabled"));
-		$match_any_rule = sql_bool_to_bool(db_fetch_result($result, 0, "match_any_rule"));
-		$inverse = sql_bool_to_bool(db_fetch_result($result, 0, "inverse"));
-		$title = htmlspecialchars(db_fetch_result($result, 0, "title"));
+		$enabled = sql_bool_to_bool($this->dbh->fetch_result($result, 0, "enabled"));
+		$match_any_rule = sql_bool_to_bool($this->dbh->fetch_result($result, 0, "match_any_rule"));
+		$inverse = sql_bool_to_bool($this->dbh->fetch_result($result, 0, "inverse"));
+		$title = htmlspecialchars($this->dbh->fetch_result($result, 0, "title"));
 
 		print "<form id=\"filter_edit_form\" onsubmit='return false'>";
 
@@ -294,10 +296,10 @@ class Pref_Filters extends Handler_Protected {
 
 		print "<ul id='filterDlg_Matches'>";
 
-		$rules_result = db_query($this->link, "SELECT * FROM ttrss_filters2_rules
+		$rules_result = $this->dbh->query("SELECT * FROM ttrss_filters2_rules
 			WHERE filter_id = '$filter_id' ORDER BY reg_exp, id");
 
-		while ($line = db_fetch_assoc($rules_result)) {
+		while ($line = $this->dbh->fetch_assoc($rules_result)) {
 			if (sql_bool_to_bool($line["cat_filter"])) {
 				$line["feed_id"] = "CAT:" . (int)$line["cat_id"];
 			}
@@ -342,10 +344,10 @@ class Pref_Filters extends Handler_Protected {
 
 		print "<ul id='filterDlg_Actions'>";
 
-		$actions_result = db_query($this->link, "SELECT * FROM ttrss_filters2_actions
+		$actions_result = $this->dbh->query("SELECT * FROM ttrss_filters2_actions
 			WHERE filter_id = '$filter_id' ORDER BY id");
 
-		while ($line = db_fetch_assoc($actions_result)) {
+		while ($line = $this->dbh->fetch_assoc($actions_result)) {
 			$line["action_param_label"] = $line["action_param"];
 
 			unset($line["filter_id"]);
@@ -417,19 +419,19 @@ class Pref_Filters extends Handler_Protected {
 
 		if (strpos($feed_id, "CAT:") === 0) {
 			$feed_id = (int) substr($feed_id, 4);
-			$feed = getCategoryTitle($this->link, $feed_id);
+			$feed = getCategoryTitle($feed_id);
 		} else {
 			$feed_id = (int) $feed_id;
 
 			if ($rule["feed_id"])
-				$feed = getFeedTitle($this->link, (int)$rule["feed_id"]);
+				$feed = getFeedTitle((int)$rule["feed_id"]);
 			else
 				$feed = __("All feeds");
 		}
 
-		$result = db_query($this->link, "SELECT description FROM ttrss_filter_types
+		$result = $this->dbh->query("SELECT description FROM ttrss_filter_types
 			WHERE id = ".(int)$rule["filter_type"]);
-		$filter_type = db_fetch_result($result, 0, "description");
+		$filter_type = $this->dbh->fetch_result($result, 0, "description");
 
 		return T_sprintf("%s on %s in %s %s", strip_tags($rule["reg_exp"]),
 			$filter_type, $feed, isset($rule["inverse"]) ? __("(inverse)") : "");
@@ -440,10 +442,10 @@ class Pref_Filters extends Handler_Protected {
 	}
 
 	private function getActionName($action) {
-		$result = db_query($this->link, "SELECT description FROM
+		$result = $this->dbh->query("SELECT description FROM
 			ttrss_filter_actions WHERE id = " .(int)$action["action_id"]);
 
-		$title = __(db_fetch_result($result, 0, "description"));
+		$title = __($this->dbh->fetch_result($result, 0, "description"));
 
 		if ($action["action_id"] == 4 || $action["action_id"] == 6 ||
 			$action["action_id"] == 7)
@@ -463,13 +465,13 @@ class Pref_Filters extends Handler_Protected {
 
 #		print_r($_REQUEST);
 
-		$filter_id = db_escape_string($this->link, $_REQUEST["id"]);
-		$enabled = checkbox_to_sql_bool(db_escape_string($this->link, $_REQUEST["enabled"]));
-		$match_any_rule = checkbox_to_sql_bool(db_escape_string($this->link, $_REQUEST["match_any_rule"]));
-		$inverse = checkbox_to_sql_bool(db_escape_string($this->link, $_REQUEST["inverse"]));
-		$title = db_escape_string($this->link, $_REQUEST["title"]);
+		$filter_id = $this->dbh->escape_string($_REQUEST["id"]);
+		$enabled = checkbox_to_sql_bool($this->dbh->escape_string($_REQUEST["enabled"]));
+		$match_any_rule = checkbox_to_sql_bool($this->dbh->escape_string($_REQUEST["match_any_rule"]));
+		$inverse = checkbox_to_sql_bool($this->dbh->escape_string($_REQUEST["inverse"]));
+		$title = $this->dbh->escape_string($_REQUEST["title"]);
 
-		$result = db_query($this->link, "UPDATE ttrss_filters2 SET enabled = $enabled,
+		$result = $this->dbh->query("UPDATE ttrss_filters2 SET enabled = $enabled,
 			match_any_rule = $match_any_rule,
 			inverse = $inverse,
 			title = '$title'
@@ -482,17 +484,17 @@ class Pref_Filters extends Handler_Protected {
 
 	function remove() {
 
-		$ids = split(",", db_escape_string($this->link, $_REQUEST["ids"]));
+		$ids = explode(",", $this->dbh->escape_string($_REQUEST["ids"]));
 
 		foreach ($ids as $id) {
-			db_query($this->link, "DELETE FROM ttrss_filters2 WHERE id = '$id' AND owner_uid = ". $_SESSION["uid"]);
+			$this->dbh->query("DELETE FROM ttrss_filters2 WHERE id = '$id' AND owner_uid = ". $_SESSION["uid"]);
 		}
 	}
 
 	private function saveRulesAndActions($filter_id) {
 
-		db_query($this->link, "DELETE FROM ttrss_filters2_rules WHERE filter_id = '$filter_id'");
-		db_query($this->link, "DELETE FROM ttrss_filters2_actions WHERE filter_id = '$filter_id'");
+		$this->dbh->query("DELETE FROM ttrss_filters2_rules WHERE filter_id = '$filter_id'");
+		$this->dbh->query("DELETE FROM ttrss_filters2_actions WHERE filter_id = '$filter_id'");
 
 		if ($filter_id) {
 			/* create rules */
@@ -521,11 +523,11 @@ class Pref_Filters extends Handler_Protected {
 			foreach ($rules as $rule) {
 				if ($rule) {
 
-					$reg_exp = strip_tags(db_escape_string($this->link, trim($rule["reg_exp"])));
+					$reg_exp = strip_tags($this->dbh->escape_string(trim($rule["reg_exp"])));
 					$inverse = isset($rule["inverse"]) ? "true" : "false";
 
-					$filter_type = (int) db_escape_string($this->link, trim($rule["filter_type"]));
-					$feed_id = db_escape_string($this->link, trim($rule["feed_id"]));
+					$filter_type = (int) $this->dbh->escape_string(trim($rule["filter_type"]));
+					$feed_id = $this->dbh->escape_string(trim($rule["feed_id"]));
 
 					if (strpos($feed_id, "CAT:") === 0) {
 
@@ -546,16 +548,16 @@ class Pref_Filters extends Handler_Protected {
 						(filter_id, reg_exp,filter_type,feed_id,cat_id,cat_filter,inverse) VALUES
 						('$filter_id', '$reg_exp', '$filter_type', $feed_id, $cat_id, $cat_filter, $inverse)";
 
-					db_query($this->link, $query);
+					$this->dbh->query($query);
 				}
 			}
 
 			foreach ($actions as $action) {
 				if ($action) {
 
-					$action_id = (int) db_escape_string($this->link, $action["action_id"]);
-					$action_param = db_escape_string($this->link, $action["action_param"]);
-					$action_param_label = db_escape_string($this->link, $action["action_param_label"]);
+					$action_id = (int) $this->dbh->escape_string($action["action_id"]);
+					$action_param = $this->dbh->escape_string($action["action_param"]);
+					$action_param_label = $this->dbh->escape_string($action["action_param_label"]);
 
 					if ($action_id == 7) {
 						$action_param = $action_param_label;
@@ -569,7 +571,7 @@ class Pref_Filters extends Handler_Protected {
 						(filter_id, action_id, action_param) VALUES
 						('$filter_id', '$action_id', '$action_param')";
 
-					db_query($this->link, $query);
+					$this->dbh->query($query);
 				}
 			}
 		}
@@ -586,35 +588,36 @@ class Pref_Filters extends Handler_Protected {
 
 		$enabled = checkbox_to_sql_bool($_REQUEST["enabled"]);
 		$match_any_rule = checkbox_to_sql_bool($_REQUEST["match_any_rule"]);
-		$title = db_escape_string($this->link, $_REQUEST["title"]);
+		$title = $this->dbh->escape_string($_REQUEST["title"]);
+		$inverse = checkbox_to_sql_bool($_REQUEST["inverse"]);
 
-		db_query($this->link, "BEGIN");
+		$this->dbh->query("BEGIN");
 
 		/* create base filter */
 
-		$result = db_query($this->link, "INSERT INTO ttrss_filters2
-			(owner_uid, match_any_rule, enabled, title) VALUES
-			(".$_SESSION["uid"].",$match_any_rule,$enabled, '$title')");
+		$result = $this->dbh->query("INSERT INTO ttrss_filters2
+			(owner_uid, match_any_rule, enabled, title, inverse) VALUES
+			(".$_SESSION["uid"].",$match_any_rule,$enabled, '$title', $inverse)");
 
-		$result = db_query($this->link, "SELECT MAX(id) AS id FROM ttrss_filters2
+		$result = $this->dbh->query("SELECT MAX(id) AS id FROM ttrss_filters2
 			WHERE owner_uid = ".$_SESSION["uid"]);
 
-		$filter_id = db_fetch_result($result, 0, "id");
+		$filter_id = $this->dbh->fetch_result($result, 0, "id");
 
 		$this->saveRulesAndActions($filter_id);
 
-		db_query($this->link, "COMMIT");
+		$this->dbh->query("COMMIT");
 	}
 
 	function index() {
 
-		$sort = db_escape_string($this->link, $_REQUEST["sort"]);
+		$sort = $this->dbh->escape_string($_REQUEST["sort"]);
 
 		if (!$sort || $sort == "undefined") {
 			$sort = "reg_exp";
 		}
 
-		$filter_search = db_escape_string($this->link, $_REQUEST["search"]);
+		$filter_search = $this->dbh->escape_string($_REQUEST["search"]);
 
 		if (array_key_exists("search", $_REQUEST)) {
 			$_SESSION["prefs_filter_search"] = $filter_search;
@@ -626,7 +629,7 @@ class Pref_Filters extends Handler_Protected {
 		print "<div id=\"pref-filter-header\" dojoType=\"dijit.layout.ContentPane\" region=\"top\">";
 		print "<div id=\"pref-filter-toolbar\" dojoType=\"dijit.Toolbar\">";
 
-		$filter_search = db_escape_string($this->link, $_REQUEST["search"]);
+		$filter_search = $this->dbh->escape_string($_REQUEST["search"]);
 
 		if (array_key_exists("search", $_REQUEST)) {
 			$_SESSION["prefs_filter_search"] = $filter_search;
@@ -706,8 +709,7 @@ class Pref_Filters extends Handler_Protected {
 
 		print "</div>"; #pane
 
-		global $pluginhost;
-		$pluginhost->run_hooks($pluginhost::HOOK_PREFS_TAB,
+		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_PREFS_TAB,
 			"hook_prefs_tab", "prefFilters");
 
 		print "</div>"; #container
@@ -832,12 +834,12 @@ class Pref_Filters extends Handler_Protected {
 
 		print "<form name='filter_new_rule_form' id='filter_new_rule_form'>";
 
-		$result = db_query($this->link, "SELECT id,description
+		$result = $this->dbh->query("SELECT id,description
 			FROM ttrss_filter_types WHERE id != 5 ORDER BY description");
 
 		$filter_types = array();
 
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
 			$filter_types[$line["id"]] = __($line["description"]);
 		}
 
@@ -864,7 +866,7 @@ class Pref_Filters extends Handler_Protected {
 		print __("in") . " ";
 
 		print "<span id='filterDlg_feeds'>";
-		print_feed_select($this->link, "feed_id",
+		print_feed_select("feed_id",
 			$cat_filter ? "CAT:$feed_id" : $feed_id,
 			'dojoType="dijit.form.FilteringSelect"');
 		print "</span>";
@@ -888,7 +890,7 @@ class Pref_Filters extends Handler_Protected {
 		$action = json_decode($_REQUEST["action"], true);
 
 		if ($action) {
-			$action_param = db_escape_string($this->link, $action["action_param"]);
+			$action_param = $this->dbh->escape_string($action["action_param"]);
 			$action_id = (int)$action["action_id"];
 		} else {
 			$action_param = "";
@@ -904,10 +906,10 @@ class Pref_Filters extends Handler_Protected {
 		print "<select name=\"action_id\" dojoType=\"dijit.form.Select\"
 			onchange=\"filterDlgCheckAction(this)\">";
 
-		$result = db_query($this->link, "SELECT id,description FROM ttrss_filter_actions
+		$result = $this->dbh->query("SELECT id,description FROM ttrss_filter_actions
 			ORDER BY name");
 
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
 			$is_selected = ($line["id"] == $action_id) ? "selected='1'" : "";
 			printf("<option $is_selected value='%d'>%s</option>", $line["id"], __($line["description"]));
 		}
@@ -928,7 +930,7 @@ class Pref_Filters extends Handler_Protected {
 			id=\"filterDlg_actionParam\" style=\"$param_hidden\"
 			name=\"action_param\" value=\"$action_param\">";
 
-		print_label_select($this->link, "action_param_label", $action_param,
+		print_label_select("action_param_label", $action_param,
 			"id=\"filterDlg_actionParamLabel\" style=\"$label_param_hidden\"
 			dojoType=\"dijit.form.Select\"");
 
@@ -953,28 +955,28 @@ class Pref_Filters extends Handler_Protected {
 
 	private function getFilterName($id) {
 
-		$result = db_query($this->link,
+		$result = $this->dbh->query(
 			"SELECT title,COUNT(DISTINCT r.id) AS num_rules,COUNT(DISTINCT a.id) AS num_actions
 				FROM ttrss_filters2 AS f LEFT JOIN ttrss_filters2_rules AS r
 					ON (r.filter_id = f.id)
 						LEFT JOIN ttrss_filters2_actions AS a
 							ON (a.filter_id = f.id) WHERE f.id = '$id' GROUP BY f.title");
 
-		$title = db_fetch_result($result, 0, "title");
-		$num_rules = db_fetch_result($result, 0, "num_rules");
-		$num_actions = db_fetch_result($result, 0, "num_actions");
+		$title = $this->dbh->fetch_result($result, 0, "title");
+		$num_rules = $this->dbh->fetch_result($result, 0, "num_rules");
+		$num_actions = $this->dbh->fetch_result($result, 0, "num_actions");
 
 		if (!$title) $title = __("[No caption]");
 
 		$title = sprintf(_ngettext("%s (%d rule)", "%s (%d rules)", $num_rules), $title, $num_rules);
 
-		$result = db_query($this->link,
+		$result = $this->dbh->query(
 			"SELECT * FROM ttrss_filters2_actions WHERE filter_id = '$id' ORDER BY id LIMIT 1");
 
 		$actions = "";
 
-		if (db_num_rows($result) > 0) {
-			$line = db_fetch_assoc($result);
+		if ($this->dbh->num_rows($result) > 0) {
+			$line = $this->dbh->fetch_assoc($result);
 			$actions = $this->getActionName($line);
 
 			$num_actions -= 1;
@@ -987,22 +989,22 @@ class Pref_Filters extends Handler_Protected {
 	}
 
 	function join() {
-		$ids = explode(",", db_escape_string($this->link, $_REQUEST["ids"]));
+		$ids = explode(",", $this->dbh->escape_string($_REQUEST["ids"]));
 
 		if (count($ids) > 1) {
 			$base_id = array_shift($ids);
 			$ids_str = join(",", $ids);
 
-			db_query($this->link, "BEGIN");
-			db_query($this->link, "UPDATE ttrss_filters2_rules
+			$this->dbh->query("BEGIN");
+			$this->dbh->query("UPDATE ttrss_filters2_rules
 				SET filter_id = '$base_id' WHERE filter_id IN ($ids_str)");
-			db_query($this->link, "UPDATE ttrss_filters2_actions
+			$this->dbh->query("UPDATE ttrss_filters2_actions
 				SET filter_id = '$base_id' WHERE filter_id IN ($ids_str)");
 
-			db_query($this->link, "DELETE FROM ttrss_filters2 WHERE id IN ($ids_str)");
-			db_query($this->link, "UPDATE ttrss_filters2 SET match_any_rule = true WHERE id = '$base_id'");
+			$this->dbh->query("DELETE FROM ttrss_filters2 WHERE id IN ($ids_str)");
+			$this->dbh->query("UPDATE ttrss_filters2 SET match_any_rule = true WHERE id = '$base_id'");
 
-			db_query($this->link, "COMMIT");
+			$this->dbh->query("COMMIT");
 
 			$this->optimizeFilter($base_id);
 
@@ -1010,14 +1012,14 @@ class Pref_Filters extends Handler_Protected {
 	}
 
 	private function optimizeFilter($id) {
-		db_query($this->link, "BEGIN");
-		$result = db_query($this->link, "SELECT * FROM ttrss_filters2_actions
+		$this->dbh->query("BEGIN");
+		$result = $this->dbh->query("SELECT * FROM ttrss_filters2_actions
 			WHERE filter_id = '$id'");
 
 		$tmp = array();
 		$dupe_ids = array();
 
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
 			$id = $line["id"];
 			unset($line["id"]);
 
@@ -1030,17 +1032,17 @@ class Pref_Filters extends Handler_Protected {
 
 		if (count($dupe_ids) > 0) {
 			$ids_str = join(",", $dupe_ids);
-			db_query($this->link, "DELETE FROM ttrss_filters2_actions
+			$this->dbh->query("DELETE FROM ttrss_filters2_actions
 				WHERE id IN ($ids_str)");
 		}
 
-		$result = db_query($this->link, "SELECT * FROM ttrss_filters2_rules
+		$result = $this->dbh->query("SELECT * FROM ttrss_filters2_rules
 			WHERE filter_id = '$id'");
 
 		$tmp = array();
 		$dupe_ids = array();
 
-		while ($line = db_fetch_assoc($result)) {
+		while ($line = $this->dbh->fetch_assoc($result)) {
 			$id = $line["id"];
 			unset($line["id"]);
 
@@ -1053,11 +1055,11 @@ class Pref_Filters extends Handler_Protected {
 
 		if (count($dupe_ids) > 0) {
 			$ids_str = join(",", $dupe_ids);
-			db_query($this->link, "DELETE FROM ttrss_filters2_rules
+			$this->dbh->query("DELETE FROM ttrss_filters2_rules
 				WHERE id IN ($ids_str)");
 		}
 
-		db_query($this->link, "COMMIT");
+		$this->dbh->query("COMMIT");
 	}
 }
 ?>
